# CHANGELOG

<!-- version list -->

## v1.2.0 (2025-12-17)

### Bug Fixes

- Cleanup docs for most recent additions ([#2](https://github.com/ameijin/quicketl/pull/2),
  [`ad76647`](https://github.com/ameijin/quicketl/commit/ad766479d3c9224e7b9a257d2795417345c3284e))

### Features

- Add multi-source pipelines (join/union), database sink, partitioned writes, and enhanced
  expressions ([#2](https://github.com/ameijin/quicketl/pull/2),
  [`ad76647`](https://github.com/ameijin/quicketl/commit/ad766479d3c9224e7b9a257d2795417345c3284e))


## v1.1.0 (2025-12-17)

### Features

- Add multi-source pipelines (join/union), database sink, partitioned writes, and enhanced
  expressions ([#1](https://github.com/ameijin/quicketl/pull/1),
  [`870077f`](https://github.com/ameijin/quicketl/commit/870077fa49a0785e1eeb32bc0d7b00c2f02c6e53))

- Add multi-source pipelines (join/union), database sink, partiti…
  ([#1](https://github.com/ameijin/quicketl/pull/1),
  [`870077f`](https://github.com/ameijin/quicketl/commit/870077fa49a0785e1eeb32bc0d7b00c2f02c6e53))


## v1.0.3 (2025-12-16)


## v1.0.2 (2025-12-16)

### Bug Fixes

- Add auto changelog
  ([`f5e942b`](https://github.com/ameijin/quicketl/commit/f5e942bd1574be1edd8a3c6bad1b62e5a3112458))


## v1.0.1 (2025-12-16)

### Documentation

- Update readme
  ([`aef6b31`](https://github.com/ameijin/quicketl/commit/aef6b3186b3dcec09b1e807c04b4eab557030b8d))


## v1.0.0 (2025-12-16)

- Initial Release
